@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
+  along with this program. If not, see https://www.gnu.org/licenses/.
 */
 
 
@@ -558,7 +558,7 @@ int TabBar::tabAt(int x)
 
 void TabBar::wheelEvent(QWheelEvent* event)
 {
-    if (event->delta() < 0)
+    if (event->angleDelta().y() < 0)
         selectNextTab();
     else
         selectPreviousTab();
